import React, { Component } from 'react'
import { Modal } from 'antd-mobile'
import styles from './AlertModal.less'
import { setBodyScroll } from '../../../pages/utils/base'

class AlertModal extends Component {
  constructor (props) {
    super(props)
    this.state = {}
  }
  componentDidMount () {
    setBodyScroll()
  }
  onCancel = () => {
    const { onCancel } = this.props 
    onCancel && onCancel()
  }
  onOk = () => {
    const { onOk } = this.props 
    this.setState({ uploading: true })
    const cb = onOk && onOk()
    if (cb instanceof Promise) {
      cb.then((res) => {
        if (!res || res.code !== 'OK') {
          this.setState({ uploading: false })
        }
      })
      .catch(() => {
        this.setState({ uploading: false })
      }) 
    } 
    return cb
  }
  componentWillUnmount () {
    setBodyScroll(true)
  }
  render () {
    const { title = '提示', content, okText = '确定' } = this.props
    const { uploading } = this.state
    return (
      <Modal 
        visible
        popup
        wrapClassName={styles['customer-alert-modal']}
        zIndex={99999}
        closable={false}
        title={title}
        animationType='slide-up'
        maskTransitionName='s'
        transitionName='slide-wrap'
        maskClosable
        onClose={this.onCancel}
        footer={
          [
            { 
              text: '取消', 
              onPress: this.onCancel
            },
            {
              text: okText,
              onPress: uploading ? null : this.onOk,
              style: {
                opacity: uploading ? 0.5 : 1
              }
            },
          ]
        }
      >
        {content}
      </Modal>
    )
  }
}
export default AlertModal
