import React, { Component } from 'react'
import { Modal, List, InputItem } from 'antd-mobile'
import styles from './ChangeModal.less'
import { setBodyScroll } from '../../../pages/utils/base'

class ChangeModal extends Component {
  constructor(props) {
    super(props)
    this.state = {}
  }
  componentDidMount() {
    setBodyScroll()
  }
  onCancel = () => {
    const { onCancel } = this.props
    onCancel && onCancel()
  }
  onOk = () => {
    const { onOk } = this.props
    this.setState({ uploading: true })
    const cb = onOk && onOk()
    if (cb instanceof Promise) {
      cb.then((res) => {
        if (!res || res.code !== 'OK') {
          this.setState({ uploading: false })
        }
      })
        .catch(() => {
          this.setState({ uploading: false })
        })
    }
    return cb
  }

  onChange = (value) => {
    this.setState({ value })
  }
  componentWillUnmount() {
    setBodyScroll(true)
  }
  render() {
    const { okText = '确定', type } = this.props
    const { uploading, value } = this.state
    let _placeholder = '请输入OCC数量'
    let _remark = '可兑换芝麻粒：'
    let _title = '兑换芝麻粒'
    if (type === 'OCC') {
      _placeholder = '请输入芝麻粒数量'
      _remark = '可兑换OCC：'
      _title = '兑换OCC'
    }
    return (
      <Modal
        visible
        popup
        wrapClassName={styles['customer-alert-modal']}
        zIndex={99999}
        closable={false}
        title={_title}
        animationType='slide-up'
        maskTransitionName='s'
        transitionName='slide-wrap'
        maskClosable
        onClose={this.onCancel}
        footer={
          [
            {
              text: '取消',
              onPress: this.onCancel
            },
            {
              text: okText,
              onPress: uploading ? null : this.onOk,
              style: {
                opacity: uploading ? 0.5 : 1
              }
            },
          ]
        }
      >
        <div className={styles['inputs-wrap']}>
          <List>
            <InputItem
              type='number'
              placeholder={_placeholder}
              onChange={this.onChange}
              value={value}
              extra='x100'
            />
            <p className={styles['remark']}>{_remark}</p>
          </List>
        </div>
      </Modal>
    )
  }
}
export default ChangeModal
