import React, { Component } from 'react'
import { Modal, List, InputItem, Toast } from 'antd-mobile'
import styles from './InputModal.less'
import { setBodyScroll } from '../../../pages/utils/base'

class InputModal extends Component {
  constructor (props) {
    super(props)
    this.state = {}
  }
  componentDidMount () {
    setBodyScroll()
  }
  onCancel = () => {
    const { onCancel } = this.props 
    onCancel && onCancel()
  }
  onOk = () => {
    const { onOk, isRequired, requiredNotice, count, countNotice } = this.props 
    const { value } = this.state
    
    if (isRequired && !value) {
      Toast.fail(requiredNotice)
      return
    }
    if (count && value < count) {
      Toast.fail(countNotice)
      return
    }
    this.setState({ uploading: true })
    const cb = onOk && onOk(value)
    if (cb instanceof Promise) {
      cb.then((res) => {
        if (!res || res.code !== 'OK') {
          this.setState({ uploading: false })
        }
      })
      .catch(() => {
        this.setState({ uploading: false })
      }) 
    } 
    return cb
  }

  onChange = (value) => {
    this.setState({ value })
  }
  componentWillUnmount () {
    setBodyScroll(true)
  }
  render () {
    const { okText = '确定', title, placeholder, explain } = this.props
    const { uploading, value } = this.state
    
    return (
      <Modal 
        visible
        popup
        wrapClassName={styles['customer-alert-modal']}
        zIndex={999}
        closable={false}
        title={title}
        animationType='slide-up'
        maskTransitionName='s'
        transitionName='slide-wrap'
        maskClosable
        onClose={this.onCancel}
        footer={
          [
            { 
              text: '取消', 
              onPress: this.onCancel
            },
            {
              text: okText,
              onPress: uploading ? null : this.onOk,
              style: {
                opacity: uploading ? 0.5 : 1
              }
            },
          ]
        }
      >
        <div className={styles['inputs-wrap']}>
          <List>
            <p className={styles['remark']}>{explain}</p>
            <InputItem
              type='number'
              placeholder={placeholder}
              onChange={this.onChange}
              value={value}
            />
          </List>
        </div>
      </Modal>
    )
  }
}
export default InputModal
