import React, { Fragment, useState, useEffect } from 'react'
import { ActivityIndicator, Result, Icon, Flex, PullToRefresh } from 'antd-mobile'
import styles from './Wrap.less'
import VConsole from 'vconsole'

export default (props) => {
  const [count, addCount] = useState(0)
  const { loading, err, errMsg, empty, loadingRender, refreshing } = props

  useEffect(() => {
    // console.log(count)
    if (count > 5) {
      const vConsole = new VConsole();
    }
  }, [count])

  //渲染主体
  const renderContent = () => {
    //加载中预渲染界面
    if (loadingRender) {
      return (
        <Fragment>
          {loading && <ActivityIndicator className={styles['wrap-activityIndicator']} toast text="加载中" />}
          <div className={loading ? `${styles.children} ${styles.filter}` : styles.children}>
            {props.children}
          </div>
        </Fragment>
      )
    }
    //加载中
    if (loading) {
      return <ActivityIndicator toast text="加载中" />
    }
    //接口错误
    if (err) {
      return (
        <div className={styles.err}>
          <Result
            img={<Icon onClick={() => addCount(count => count + 1)} type="cross-circle" className={styles['icon-err']} />}
            title="信息错误"
            message={errMsg}
          />
        </div>
      )
    }
    //空页面
    if (empty) {
      return (
        <Flex className={styles.empty} align="center" justify="center">
          <div>
            <img className={styles['icon-empty']} src={require('./assets/icon_empty.png')} />
            <div className={styles.message}>~空数据~</div>
          </div>
        </Flex>
      )
    }
    //正常
    return props.children
  }

  return (
    <div className={styles.wrap}>

      {props.onRefresh && (
        <PullToRefresh
          className={styles.pullRefresh}
          damping={window.devicePixelRatio * 25}
          distanceToRefresh={window.devicePixelRatio * 25}
          style={{
            overflow: 'auto',
          }}
          direction="down"
          refreshing={refreshing}
          onRefresh={() => {
            props.onRefresh()
          }}
        >
          <div className={styles['pull-content']}></div>
        </PullToRefresh>
      )}

      {renderContent()}
    </div>
  )
}