import React, { Component, Fragment } from 'react';
import { ActivityIndicator, Toast } from 'antd-mobile';
import styles from './home.less';
import Homechild from './Homechild';
import { getPageData } from '../services/milldetail';
import Tabbar from '@/components/Tabbar/index';
import Titlebar from '@/components/Titlebar/Titlebar';

export default class Home extends Component {
  constructor(props) {
    super(props);
    document.title = this.props.route.name;
    this.state = {
      tabgNum: 0,
      equityData: [],
      scripData: [],
      pageIndex: 1,
      isScroll: true,
      isAnimating: false,
      total: null
    }
  }

  async componentDidMount() {
    this.getRequest();
  }

  onChangeTabs = (index) => {
    this.setState({ tabgNum: index, pageIndex: 1, }, () => {
      this.getRequest();
    });
  }

  //测试：第一次请求数据
  getRequest = async () => {
    const { tabgNum, pageIndex } = this.state;
    const payload = {
      pageIndex: pageIndex,
      pageSize: 10,
      type: tabgNum == 0 ? 20 : 10
    }
    const _state = { isScroll: true, isAnimating: false };
    this.setState({ isScroll: false, isAnimating: true });
    try {
      const data = await getPageData(payload);
      if (data.code === 'OK' && data.success) {
        if (this.state.tabgNum === 0) {
          this.setState({ scripData: data.data.list, total: data.data.total })
        }
        else {
          this.setState({ equityData: data.data.list, total: data.data.total })
        }
      }
      else {
        Toast.fail(data.msg, 1);
      }
    } catch (error) {
      console.log(error);
    } finally {
      this.setState(_state);
    }
  }

  //滚动请求数据
  scrollRequest = async () => {
    const { tabgNum, pageIndex } = this.state;
    const payload = {
      pageIndex: pageIndex + 1,
      pageSize: 10,
      type: tabgNum == 0 ? 20 : 10
    }
    const _state = { isScroll: true, isAnimating: false };
    this.setState({ isScroll: false, isAnimating: true });
    try {
      const data = await getPageData(payload);
      if (data.code === 'OK' && data.success) {
        if (tabgNum === 0) {
          this.setState({
            scripData: this.state.scripData.concat(data.data.list),
            pageIndex: this.state.pageIndex + 1
          });
        }
        else {
          this.setState({
            equityData: this.state.equityData.concat(data.data.list),
            pageIndex: this.state.pageIndex + 1
          });
        }
      }
      else {
        Toast.fail(data.msg, 1);
      }
    } catch (error) {
      console.log(error);
    } finally {
      this.setState(_state);
    }
  }

  render() {
    const { tabgNum, scripData, equityData, isScroll, isAnimating, total } = this.state;
    return (
      <Fragment>
        <div className={styles.mill_wrap}>
          <Titlebar
            onChange={(index) => this.onChangeTabs(index)}
            tabgNum={tabgNum}
            title='下午好  欢迎来WOS钱包'
            scription='开始投资最好的时机是十年前和今天哦'
          />
          <div style={isAnimating ? { filter: 'blur(10px)' } : null}>
            <Homechild
              scrollRequest={() => this.scrollRequest()}
              tabgNum={tabgNum}
              data={tabgNum === 0 ? scripData : equityData}
              isScroll={isScroll}
              total={total}
              isAnimating={isAnimating}
            />
          </div>
          <Tabbar tabSign={'home'} />
        </div>
        <ActivityIndicator
          toast
          text="加载中"
          animating={isAnimating}
        />
      </Fragment>
    )
  }
}
