import React, { Component, Fragment } from 'react'
import styles from './homechild.less';
import router from 'umi/router';
import { getDocRec } from '../utils/base';
import namesign from '../../assets/namesign.png';
import { hasInvite } from '../services/order.js';
import Textmodals from '@/components/Textmodals/Textmodals';
import { Toast } from 'antd-mobile';
export default class Homechild extends Component {
  constructor(props) {
    super(props);
    this.state = {
      isExchange: false
    }
  }
  //去购买
  onBuymill = async (tid) => {
    try {
      const res = await hasInvite();
      if (res.success) {
        res.data ? router.push(`/mill/buymill?tabg=${this.props.tabgNum}&tid=${tid}`) : this.setState({ isExchange: true })
      }
      else {
        Toast.fail(res.msg, 1);
      }
    } catch (error) {
      console.log(error)
    }
  }

  componentDidMount() {
    this.wrapContent.addEventListener('scroll', this.bindScroll);
  }

  //监听事件
  bindScroll = () => {
    // 滚动的高度
    const scrollTop = this.wrapContent.scrollTop
    // 视窗高度
    const clientHeight = getDocRec('docHeight').docHeight
    // 页面高度
    const scrollHeight = this.contentContainer.offsetHeight
    // 距离页面底部的高度
    const height = scrollHeight - scrollTop - clientHeight
    // console.log(height, 'height')
    // 判断距离页面底部的高度 
    if (height <= 200) {
      const { scrollRequest, isScroll, data, total } = this.props;
      if (isScroll && data.length < total) {
        scrollRequest()
      }
    }
  }

  componentWillUnmount() {
    // 移除滚动监听
    this.wrapContent.removeEventListener('scroll', this.bindScroll);
  }

  render() {
    const { data, total, isAnimating } = this.props;
    return (
      <div
        className={isAnimating ? 'filter-blur' : ''}
        style={{ overflowY: 'scroll', height: isAnimating ? '100vh' : '67vh' }}
        ref={node => this.wrapContent = node}
      >
        <div ref={node => this.contentContainer = node}>
          {
            data.map((item, index) => {
              return (
                <div
                  onClick={() => this.onBuymill(item.tid)}
                  key={index}
                  className={styles.homechild_wrap}>
                  <div className={styles.header}>
                    <div className={styles.headerLeft}>
                      <img src={namesign} alt="error" />
                      {item.name}
                    </div>
                    {item.isLimit ? <div className={styles.headerRight}>限量特价</div> : null}
                  </div>
                  {
                    item.isLimit ?
                      <Fragment>
                        <div className={styles.purchasingWrap}>
                          <div className={styles.contentHeader}>
                            <div className={styles.contentLeft}>
                              <div>{!!item.description ? item.description.power : ''}</div>
                              <div>单份算力</div>
                              <div>每人限购
                              {item?.perUserLimit ?? ''}份
                            </div>
                            </div>
                            <div className={styles.buyBtnLess}>立即购买</div>
                          </div>
                          <div className={styles.fill}></div>
                          <div className={styles.footer}>剩余份数&nbsp;&nbsp;{item?.stockQuantity ?? ''}份</div>
                        </div>
                      </Fragment>
                      :
                      <Fragment>
                        <div className={styles.main_content}>
                          <span>单份算力</span>
                          <span className={styles.child_color}>{item?.description?.power ?? ''}</span>
                        </div>
                        <div className={styles.main_content}>
                          <span>每人限购</span>
                          <span>不限量</span>
                        </div>
                        <div className={styles.headerFill}></div>
                        <div className={styles.main_content}>
                          <div style={{ color: '#000000' }}>
                            <span>剩余份数:</span>
                            <span style={{ marginLeft: '2vw' }}>库存充足</span>
                          </div>
                          <div className={styles.buyBtn}>立即购买</div>
                        </div>
                      </Fragment>
                  }
                </div>
              )
            })
          }
          {data.length < total || total < 10 ? null : <div className={styles.footer_text}>数据已加载完毕~~</div>}
        </div>
        <Textmodals
          footerType={true}
          onClose={() => this.setState({ isExchange: false })}
          isShow={this.state.isExchange}
          title='购买提示'
          text='必须绑定邀请人才能购买矿机，快去绑定吧！'
          onSure={()=>router.push('/team')}
        />
      </div>
    )
  }
}
