import React, { Component, lazy, Suspense, Fragment } from 'react';
import { ActivityIndicator } from 'antd-mobile';
import styles from './milldetail.less';
import { getPageList } from '../services/order';
import Titlebar from '@/components/Titlebar/Titlebar';
const Childcontent = lazy(() => import('./Childcontent'));

export default class Milldetail extends Component {
  constructor(props) {
    super(props);
    this.state = {
      tabgNum: Number(this.props.location.query.tabg) || 0,
      equityData: [],
      scripData: [],
      pageIndex: 1,
      isScroll: true,
      isAnimating: false,
      total: null
    }
  }

  async componentDidMount() {
    document.title = '矿机详情';
    this.getRequest()
  }

  onChangeTabs = (index) => {
    this.setState({ tabgNum: index, pageIndex: 1, }, () => {
      this.getRequest();
    });
  }

  //测试：第一次请求数据
  getRequest = async () => {
    const { tabgNum, pageIndex } = this.state;
    const payload = {
      pageIndex: pageIndex,
      pageSize: 10,
      minerType: tabgNum == 0 ? 20 : 10
    }
    const _state = { isScroll: true, isAnimating: false };
    this.setState({ isScroll: false, isAnimating: true });
    try {
      const data = await getPageList(payload);
      if (data.code === 'OK' && data.success) {
        if (this.state.tabgNum === 0) {
          this.setState({ scripData: data.data.list, total: data.data.total })
        }
        else {
          this.setState({ equityData: data.data.list, total: data.data.total })
        }
      }
      else {
        Toast.fail(data.msg, 1);
      }
    } catch (error) {
      console.log(error);
    } finally {
      this.setState(_state);
    }
  }

  //滚动请求数据
  scrollRequest = async () => {
    const { tabgNum, pageIndex } = this.state;
    const payload = {
      pageIndex: pageIndex + 1,
      pageSize: 10,
      minerType: tabgNum == 0 ? 20 : 10
    }
    const _state = { isScroll: true, isAnimating: false };
    this.setState({ isScroll: false, isAnimating: true });
    try {
      const data = await getPageList(payload);
      if (data.code === 'OK' && data.success) {
        if (tabgNum === 0) {
          this.setState({
            scripData: this.state.scripData.concat(data.data.list),
            pageIndex: this.state.pageIndex + 1
          });
        }
        else {
          this.setState({
            equityData: this.state.equityData.concat(data.data.list),
            pageIndex: this.state.pageIndex + 1
          });
        }
      }
      else {
        Toast.fail(data.msg, 1);
      }
    } catch (error) {
      console.log(error);
    } finally {
      this.setState(_state);
    }
  }

  render() {
    const { tabgNum, scripData, equityData, isScroll, isAnimating, total } = this.state;
    return (
      <Fragment>
        <Titlebar
          onChange={(index) => this.onChangeTabs(index)}
          tabgNum={tabgNum}
          title='我的矿机'
          scription='坚持不懈地为你制造收益'
        />
        <div className={isAnimating ? `filter-blur ${styles.mill_wrap}` : styles.mill_wrap}>
          <Suspense fallback={null}>
            <Childcontent
              scrollRequest={() => this.scrollRequest()}
              tabgNum={tabgNum}
              data={tabgNum === 0 ? scripData : equityData}
              isScroll={isScroll}
              total={total}
              getRequest={this.getRequest}
            />
          </Suspense>
        </div>
        <ActivityIndicator
          toast
          text="加载中..."
          animating={isAnimating}
        />
      </Fragment>
    )
  }
}
