import React, { Component, Fragment } from 'react';
import styles from './Myinvitation.less';
import Activity from '@/components/Activity';
import { getScroll, getDocRec } from '../../utils/base';
import { getPageList } from '../../services/mine';
import Result from '../../../components/Result';
import defaultImg from '../../../assets/defatult.png';
import moment from 'moment';

export default class Myinvitation extends Component {
  constructor(props) {
    super(props);
    document.title = this.props.route.name;
    this.state = {
      isActivity: false,
      loading: true,
      pageIndex: 1,
      allList: [],
      total: null
    }
  }

  componentDidMount() {
    window.addEventListener('scroll', this.bindScroll);
    this.getListData(1)
  }

  getListData = async (pageIndex) => {
    try {
      this.setState({ isActivity: true, loading: false });
      let obj = {
        pageIndex: pageIndex,
        pageSize: 10
      }
      const res = await getPageList(obj);
      if (res.code === 'OK' && res.success && !!res.data.list) {
        this.setState({ pageIndex: pageIndex, allList: this.state.allList.concat(res.data.list) });
      }
    } catch (error) {
      console.log(error);
    } finally { this.setState({ isActivity: false, loading: true }) }
  }

  bindScroll = () => {
    // 滚动的高度
    const scrollTop = getScroll(window, 'top');
    // 视窗高度
    const clientHeight = getDocRec('docHeight').docHeight
    // 页面高度
    const scrollHeight = this.contentContainer.offsetHeight
    // 距离页面底部的高度
    const height = scrollHeight - scrollTop - clientHeight
    // 判断距离页面底部的高度 
    if (height <= 200) {
      const { total, loading, pageIndex, allList } = this.state;
      if (loading) {
        if (allList.length < total) {
          this.getListData(pageIndex + 1);
        }
      }
    }
  }

  componentWillUnmount() {
    window.removeEventListener('scroll', this.bindScroll);
  }

  render() {
    const { isActivity, allList, total } = this.state;
    return (
      <Fragment>
        {allList.length === 0 ? null : <div style={{ height: '4vw' }}></div>}
        <div
          ref={node => this.contentContainer = node}
          style={isActivity ? { filter: 'blur(10px)' } : null}
          className={styles.invitationWrap}
        >
          {
            allList.length === 0 ? <Result style={{ height: '100vh' }} /> :
              allList.map((item, index) => {
                return (
                  <div key={index} className={styles.content}>
                    <img src={!!item.avatar && item.avatar !== '-' ? item.avatar : defaultImg} alt="error" />
                    <div className={styles.description}>
                      <div>{item.nickname || ''}</div>
                      <div>{moment(item.createTime).format('YYYY-MM-DD HH:MM:ss')}</div>
                    </div>
                  </div>
                )
              })
          }
          {allList.length < total || total < 10 ? null : <div className={styles.toastText}>数据加载完毕</div>}
        </div>
        <Activity isActivity={isActivity} />
      </Fragment>
    )
  }
}
