import React, { Component, Fragment } from 'react';
import styles from './team.less';
import Tabbar from '@/components/Tabbar/index';
import Header from './Header/Header';
import { WingBlank, Toast } from 'antd-mobile';
import CopyToClipboard from 'react-copy-to-clipboard';
import defaultImg from '../../assets/defatult.png';
import { getInviteCode, getInviteSummary } from '../services/mine';
import Activity from '@/components/Activity';
import router from 'umi/router';

export default class Team extends Component {
  constructor(props) {
    super(props);
    document.title = this.props.route.name
    this.state = {
      sign: 1,
      invitationCode: null,
      isActivity: false,
      myData: {},
      parent: {}
    }
  }

  onCopy = (value, result) => {
    if (!!value && result) {
      Toast.success('复制成功', 1);
    }
    else {
      Toast.fail('复制失败,请再次尝试~', 1);
    }
  }

  componentDidMount() {
    this.getCode();
  }

  //获取邀请码
  getCode = async () => {
    try {
      this.setState({ isActivity: true })
      const res = await getInviteCode();
      //我的邀请摘要
      const data = await getInviteSummary();
      if (res.code === 'OK' && res.success && data.code === 'OK' && data.success) {
        this.setState({ invitationCode: res.data, myData: data.data, parent: data.data.parent });
      }
    } catch (error) {
      console.log(error);
    } finally { this.setState({ isActivity: false }) }
  }



  render() {
    const { invitationCode, isActivity, myData, parent } = this.state;
    return (
      <Fragment>
        <div style={isActivity ? { filter: 'blur(10px)' } : null}>
          <WingBlank size='lg' style={{ paddingTop: '4vw' }}>
            <div className={styles.headerWrap}>
              <Header title='我的团队' btnText='详情' />
              <div className={styles.headerFooter}>
                <div style={{ borderRight: 'solid 2px #E8EBF4' }} className={styles.content}>
                  <span>团队人数</span>
                  <span>{!!myData.teamInviteCount || myData.teamInviteCount === 0 ? myData.teamInviteCount : ''}</span>
                </div>
                <div className={styles.content}>
                  <span>我的邀请</span>
                  <span>{!!myData.myInviteCount || myData.myInviteCount === 0 ? myData.myInviteCount : ''}</span>
                </div>
              </div>
            </div>
            <div className={styles.mainWrap}>
              <Header title='我的邀请人' />
              <div className={styles.invitationPople}>
                {
                  !!parent ?
                    <div className={styles.showTitleimg}>
                      <img src={!!parent.avatar ? parent.avatar : defaultImg} alt="error" />
                      <div className={styles.code}>
                        <span>{parent.nickname}</span>
                        <span>邀请码：{parent.code}</span>
                      </div>
                    </div> :
                    <div className={styles.showContent}>
                      <div className={styles.left}>
                        <span>请绑定邀请人</span>
                        <span>输入邀请人的邀请码绑定关系</span>
                      </div>
                      <div onClick={() => router.push('/inviter')} className={styles.right}>绑定</div>
                    </div>
                }
              </div>
              <div className={styles.fill}></div>
              <div className={styles.invitationCode}>
                <div className={styles.codeContent}>
                  <div className={styles.left}>
                    <span>我的邀请码</span>
                    <span>{invitationCode}</span>
                  </div>
                  <CopyToClipboard
                    text={invitationCode}
                    onCopy={this.onCopy}
                  >
                    <div className={styles.right}>复制</div>
                  </CopyToClipboard>
                </div>
              </div>
            </div>
          </WingBlank>
          <Tabbar tabSign={'team'} />
        </div>
        <Activity isActivity={isActivity} />
      </Fragment>
    )
  }
}
