import React, { Component } from 'react';
import styles from './wosdetail.less';
import { Tabs } from 'antd-mobile';
import Activity from '@/components/Activity';
import { getScroll, getDocRec } from '../utils/base';
import WOSchild from './WOSchild/WOSchild';
import { getWOSPageList } from '../services/billdetail';

export default class WOSdetail extends Component {
  constructor(props) {
    super(props);
    document.title = this.props.route.name;
    this.state = {
      tabs: [
        { title: '全部' },
        { title: '充值' },
        { title: '转赠' },
        { title: '提取' },
        { title: '收益' },
        { title: '转出' }
      ],
      isActivity: false,
      tabgNum: 0,
      pageIndex: 1,
      allList: [1, 2, 3, 4],
      total: null,
      loading: true,
    }
  }

  componentDidMount() {
    window.addEventListener('scroll', this.bindScroll);
    this.onRequest();
  }

  bindScroll = () => {
    // 滚动的高度
    const scrollTop = getScroll(window, 'top');
    // 视窗高度
    const clientHeight = getDocRec('docHeight').docHeight
    // 页面高度
    const scrollHeight = this.contentContainer.offsetHeight
    // 距离页面底部的高度
    const height = scrollHeight - scrollTop - clientHeight
    // 判断距离页面底部的高度 
    if (height <= 200) {
      const { tabgNum, total, loading, pageIndex, allList } = this.state;
      if (loading) {
        if (allList.length < total) {
          this.onScrollrequest(tabgNum, pageIndex + 1);
        }
      }
    }
  }

  //滚动事件列表请求
  onScrollrequest = async (tabgNum, pageIndex) => {
    try {
      this.setState({ isActivity: true, loading: false });
      const obj = {
        pageIndex: pageIndex,
        pageSize: 10,
        type: tabgNum
      }
      const res = await getWOSPageList(obj);
      if (res.code === 'OK' && res.success) {
        this.setState({ pageIndex: pageIndex, allList: this.state.allList.concat(res.data.list) });
      }
    } catch (error) {
      console.log(error);
    } finally { this.setState({ isActivity: false, loading: true }) }
  }

  componentWillUnmount() {
    window.removeEventListener('scroll', this.bindScroll);
  }

  //tags切换事件
  onChangeTabs = (tab, index) => {
    this.setState({ tabgNum: index, pageIndex: 1 }, () => {
      this.onRequest();
    });
  }

  //请求列表
  onRequest = async () => {
    this.setState({ isActivity: true });
    try {
      const { tabgNum, pageIndex } = this.state;
      const obj = {
        pageIndex: pageIndex,
        pageSize: 10,
        type: tabgNum
      }
      const res = await getWOSPageList(obj);
      if (res.code === 'OK' && res.success) {
        this.setState({
          allList: res.data.list,
          total: res.data.total
        });
      }
    } catch (error) {
      console.log(error);
    } finally { this.setState({ isActivity: false }) };
  }

  render() {
    const { isActivity, tabs, tabgNum, allList, total } = this.state;
    return (
      <div ref={node => this.contentContainer = node} className={styles.record_wrap}>
        <div className={styles.list_wrap} style={isActivity ? { filter: 'blur(10px)' } : null}>
          <Tabs tabs={tabs}
            initialPage={tabgNum}
            onChange={this.onChangeTabs}
            tabBarActiveTextColor='#3B7BE6'
            swipeable={false}
          >
            <WOSchild list={allList} total={total} tabgNum={tabgNum} />
          </Tabs>
        </div>
        <Activity isActivity={isActivity} />
      </div>
    )
  }
}
