import React, { Component, Fragment } from 'react';
import { Toast } from 'antd-mobile';
import styles from './Wallet.less';
import CopyToClipboard from 'react-copy-to-clipboard';
import Activity from '@/components/Activity';
import { getAccountAddress } from '../services/mine';

export default class Wallet extends Component {
  constructor(props) {
    super(props);
    this.state = {
      url: null,
      isActivity: false
    }
  }

  onCopy = (value, result) => {
    if (!!value && result) {
      Toast.success('复制成功', 1);
    }
    else {
      Toast.fail('复制失败,请再次尝试~', 1);
    }
  }

  async componentDidMount() {
    this.setState({ isActivity: true });
    const res = await getAccountAddress();
    try {
      if (res.code === 'OK' && res.success) {
        this.setState({ url: res.data, isActivity: false });
      }
      else {
        Toast.fail(res.msg, 1);
      }
    } catch (error) {
      console.log(error);
    } finally {
      this.setState({ isActivity: false })
    }
  }

  render() {
    const { url, isActivity } = this.state;
    document.title = this.props.route.name
    return (
      <Fragment>
        <div className={styles.wingblack} style={isActivity ? { filter: 'blur(10px)' } : null}>
          <div className={styles.wallet_wrap}>
            <div className={styles.header}>
              <span style={{ fontWeight: 'bold' }}>钱包地址</span>
              <CopyToClipboard
                text={url}
                onCopy={this.onCopy}
              >
                <span className={styles.copyText}>复制地址</span>
              </CopyToClipboard>
            </div>
            <div className={styles.Wallet_adress}>{url}</div>
            <div style={{ width: '100%', borderTop: 'solid 1px #E5E5E5' }}></div>
          </div>
          <div className={styles.footer}>
            <span>充值说明</span>
            <div style={{ marginTop: '2.8vw' }} className={styles.text_descript}>1、请勿向上述以外的钱包地址充值，若发生地址错误资产将无法找回；</div>
            <div style={{ marginTop: '1vw' }} className={styles.text_descript}>2、充值无须进行人工审核，正常会在20分钟到账，取决于链上网络。</div>
          </div>
        </div>
        <Activity isActivity={isActivity} />
      </Fragment>
    )
  }
}
