import router from 'umi/router'
import { Base64 as Base64Npm } from 'js-base64'
import { Mask, MaskQcode } from '@/components'
import UserAgent from './UserAgent'
import Url from './Url'

export const Base64 = Base64Npm

// 芝麻下载地址
export const zhimaDownUrl = '//d.6short.com/ght4?utm_source=fir&utm_medium=qr'

export const pushLocation = (_location) => {
  router.push(_location)
}

// -----------
// ----------- 环境判断类 ----------
// -----------
const USERAGENT = window.navigator.userAgent
//判断微信
export const isWeixin = () => {
  const ua = USERAGENT.toLowerCase();
  const _match = ua.match(/MicroMessenger/i)
  return !!_match && _match[0] === 'micromessenger'
}

// 判断安卓
export const isAndroid = () => {
  return USERAGENT.indexOf('Android') > -1 || USERAGENT.indexOf('Linux') > -1; //g
}
// 判断ios
export const isIos = () => {
  return !!USERAGENT.match(/\(i[^;]+;( U;)? CPU.+Mac OS X/); //ios终端
}
// 判断是否是在 App 中
export const isApp = () => {
  return (USERAGENT.indexOf('com.starbuds') > -1) || (location.host.indexOf('localhost') > -1) || Url.getQueryString('a') === '1'
}

export const isPc = () => {
  var userAgentInfo = navigator.userAgent;
  var Agents = new Array("Android", "iPhone", "SymbianOS", "Windows Phone", "iPad", "iPod");
  var flag = true;
  for (var v = 0; v < Agents.length; v++) {
    if (userAgentInfo.indexOf(Agents[v]) > 0) {
      flag = false;
      break;
    }
  }
  // pc true phone false
  return flag;
}

// 获取渠道号
export const getChannelId = () => {
  // 芝麻直播 - ios
  let _channelId = '78139153711104'
  if (isAndroid()) {
    // 芝麻直播 - android
    _channelId = '78139153711104'
  }
  return _channelId
}

// 获取滚动高度
export const getScroll = (win, top) => {
  // window.pageXOffset 
  let ret = win[`page${top ? 'Y' : 'X'}Offset`];
  const method = `scroll${top ? 'Top' : 'Left'}`;
  if (typeof ret !== 'number') {
    const d = win.document;
    // documentElement
    ret = d.documentElement[method];
    if (typeof ret !== 'number') {
      // body
      ret = d.body[method];
    }
  }
  return ret;
}

// body 禁止滚动
const preventDefaultFunc = function (e) {
  e.preventDefault()
}
export const setBodyScroll = (isAllow) => {
  const _body = document.body
  if (isAllow) {
    // _body.style.overflow = 'unset' 
    _body.removeEventListener('touchmove', preventDefaultFunc)
    return
  }
  // _body.style.overflow = 'hidden' 
  _body.addEventListener('touchmove', preventDefaultFunc, { passive: false })
}

// 获取文档高度 宽度
export const getDocRec = () => {
  const docHeight = document.documentElement.clientHeight
  const docWidth = document.documentElement.clientWidth
  return {
    docHeight, docWidth
  }
}

// 获取文档滚动高度
export const getDocScroll = (name) => {
  const scrollHeight = document.documentElement.scrollHeight || document.body.scrollHeight
  const scrollWidth = document.documentElement.scrollWidth || document.body.scrollWidth
  const result = {
    scrollHeight, scrollWidth
  }
  return name ? result[name] : result
}


// 获取时间
export const getDate = (nDate = (new Date()), fmt = 'yyyy-MM-dd hh:mm:ss') => {
  const sDate = new Date(nDate)
  const dateObj = {
    'M+': sDate.getMonth() + 1,
    'd+': sDate.getDate(),
    'h+': sDate.getHours(),
    'm+': sDate.getMinutes(),
    's+': sDate.getSeconds(),
    'q+': Math.floor((sDate.getMonth() + 3) / 3),
    'S': sDate.getMilliseconds()
  }
  if (/(y+)/.test(fmt)) {
    fmt = fmt.replace(RegExp.$1, (sDate.getFullYear() + '')
      .substr(4 - RegExp.$1.length))
  }
  for (const s in dateObj) {
    if (new RegExp('(' + s + ')').test(fmt)) {
      fmt = fmt.replace(RegExp.$1, (RegExp.$1.length === 1)
        ? (dateObj[s])
        : (('00' + dateObj[s]).substr(('' + dateObj[s]).length)))
    }
  }
  return fmt
}

export const formatExpireTime = (timeStamp) => {

  const _result = {}
  if (!timeStamp) {
    return _result
  }
  const baseStamp = parseInt(timeStamp / 1000)
  _result.days = parseInt(baseStamp / (3600 * 24))
  const baseHour = baseStamp % (3600 * 24)
  _result.hours = parseInt(baseHour / 3600)
  return _result
}

// 钱包货币类型
export const walletTypeArray = [
  { key: 11, value: '星钻' },
  { key: 12, value: '星元' },
  { key: 21, value: '星币' },
]

// 复制文本
export const copyText = (value, cb) => {
  if (!value) {
    return
  }
  // for modern browser
  if (document.execCommand) {
    var element = document.createElement('SPAN')
    element.textContent = value
    document.body.appendChild(element)
    if (document.selection) {
      let range = document.body.createTextRange()
      range.moveToElementText(element)
      range.select()
    } else if (window.getSelection) {
      let range = document.createRange()
      range.selectNode(element)
      window.getSelection().removeAllRanges()
      window.getSelection().addRange(range)
    }
    document.execCommand('copy')
    element.remove ? element.remove() : element.removeNode(true)
  }
  // for ie
  if (window.clipboardData) {
    window.clipboardData.setData('text', value)
  }
  cb && cb()
}

// 芝麻粒兑换倍数
export const coinMultiple = 100

export const userRole = {
  1: '小芝麻',
  2: '素人',
  3: '达人',
  4: '网红',
  5: '天后',
  6: '天王',
  7: '影后',
  8: '影帝',
  9: '城市合伙人',
  10: '全球合伙人'
}


// 自动下载时间啊
export const DOWN_MS = 500000
let maskInstance = null
// let certInstance = null
// 下载
export const onDownLoadApp = () => {
  // 在pc打开 直接显示二维码
  if (isPc()) {
    MaskQcode()
    return
  }
  // app 中 return 掉
  if (isApp()) {
    return
  }
  // 微信弹出mask 让用浏览器打开
  if (UserAgent.wechat()) {
    if (maskInstance) {
      return
    }
    maskInstance = Mask({
      onCancel: () => {
        maskInstance = null
      }
    })
    return
  }

  const _versionDownloadUrl = 'https://starbuds.paqukeji.com/download/' + getChannelId() + '?s=1'

  // 安卓直接下载
  if (isAndroid()) {
    window.location.href = _versionDownloadUrl // '//zmopen.pro/down/zhima.apk'
  } else {
    // ios 下载
    //渠道下载
    // window.location.href = _versionDownloadUrl
    // `itms-services://?action=download-manifest&url=//zmopen.pro/down/zhima.ipa`
    const script = document.createElement('script')
    script.src = _versionDownloadUrl
    script.type = 'text/javascript'
    document.body.appendChild(script)
    setTimeout(() => {
      window.alert('您可以切换到桌面查看安装进度')
    }, 3000)
  }
}

//映射title文案
export const titleMap = new Map([
  [10, '购买矿机'],
  [20, '矿机收益'],
  [30, '用户充值-USDT'],
  [31, '用户充值-共享值'],
  [40, '用户兑换-转入-WOS'],
  [41, '用户兑换-转出-USDT'],
  [50, '用户赠币-转入'],
  [51, '用户赠币-转出'],
  [60, '用户提币申请-WOS'],
  [61, '用户提币申请结果-WOS-失败'],
  [70, '邀请收益-WOS（动态奖励）'],
  [71, '邀请收益-共享值']
])

